from fastapi import FastAPI, Depends
from sqlalchemy.orm import Session
from api.database import get_db
from api.models import Message
from fastapi.middleware.cors import CORSMiddleware

app = FastAPI()

app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_methods=["*"],
    allow_headers=["*"],
)

@app.get("/messages")
def get_messages(order_by: str = "id", take: int = 10, skip: int = 0, db: Session = Depends(get_db)):
    order_by_field = getattr(Message, order_by, None)
    if order_by_field is None:
        return {"error": f"Invalid order_by field: {order_by}"}
    messages = db.query(Message).order_by(order_by_field).offset(skip).limit(take).all()
    return messages